@@ -1,5 +1,4 @@
-# cython: profile=True
-# Time-stamp: <2013-03-05 16:49:06 Tao Liu>
+# Time-stamp: <2013-04-15 18:05:14 Tao Liu>
 
 """Description: MACS 2 main executable
 
@@ -212,13 +211,19 @@ def run( args ):
             info("#3 User prefers to use random sampling instead of linear scaling.")
             if t1 > c1:
                 info("#3 MACS is random sampling treatment %ss...", tag)
-                warn("#3 Your results may not be reproducible due to the random sampling!")
-                treat.sample_num(c1)
-                info("#3 %d tags from treatment are kept", treat.total)                
+                if options.seed < 0:
+                    warn("#3 Your results may not be reproducible due to the random sampling!")
+                else:
+                    info("#3 Random seed (%d) is used." % options.seed)
+                treat.sample_num(c1, options.seed)
+                info("#3 %d Tags from treatment are kept", treat.total)                
             elif c1 > t1: 
                 info("#3 MACS is random sampling control %ss...", tag)
-                warn("#3 Your results may not be reproducible due to the random sampling!")
-                control.sample_num(t1)
+                if options.seed < 0:
+                    warn("#3 Your results may not be reproducible due to the random sampling!")
+                else:
+                    info("#3 Random seed (%d) is used." % options.seed)
+                control.sample_num(t1, options.seed)
                 info("#3 %d %ss from control are kept", control.total, tag)
             # set options.tocontrol although it would;t matter now
             options.tocontrol = False
@@ -249,16 +254,16 @@ def run( args ):
     peakdetect.call_peaks()
 
     #call refinepeak if needed.
-    if options.refine_peaks:
-        info("#3 now put back duplicate reads...")
-        treat.addback_dups()
-        info("#3 calculate reads balance to refine peak summits...")
-        refined_peaks = treat.refine_peak_from_tags_distribution ( peakdetect.peaks, options.d, 0 )
-        info("#3 reassign scores for newly refined peak summits...")
-        peakdetect.peaks = peakdetect.scoretrack.reassign_peaks( refined_peaks ) # replace
-        #info("#3 write to file: %s ..." % options.name+"_refined_peaks.encodePeak" )
-        #refinedpeakfile = open(options.name+"_refined_peaks.encodePeak", "w")
-        #refined_peaks.write_to_narrowPeak (refinedpeakfile, name_prefix="%s_refined_peak_", name=options.name, score_column=score_column, trackline=options.trackline )
+    # if options.refine_peaks:
+    #     info("#3 now put back duplicate reads...")
+    #     treat.addback_dups()
+    #     info("#3 calculate reads balance to refine peak summits...")
+    #     refined_peaks = treat.refine_peak_from_tags_distribution ( peakdetect.peaks, options.d, 0 )
+    #     info("#3 reassign scores for newly refined peak summits...")
+    #     peakdetect.peaks = peakdetect.scoretrack.reassign_peaks( refined_peaks ) # replace
+    #     #info("#3 write to file: %s ..." % options.name+"_refined_peaks.encodePeak" )
+    #     #refinedpeakfile = open(options.name+"_refined_peaks.encodePeak", "w")
+    #     #refined_peaks.write_to_narrowPeak (refinedpeakfile, name_prefix="%s_refined_peak_", name=options.name, score_column=score_column, trackline=options.trackline )
 
     #diag_result = peakdetect.diag_result()
     #4 output
@@ -279,7 +284,7 @@ def run( args ):
     if options.nolambda:
         ofhd_xls.write("# local lambda is disabled!\n")
     # pass write method so we can print too, and include name
-    peakdetect.toxls(ofhd_xls, name = options.name)
+    peakdetect.peaks.write_to_xls(ofhd_xls, name = options.name)
     ofhd_xls.close()
     #4.2 peaks in BED
     if options.log_pvalue:
